TODO

- add example usage in ableton project to README as a reference for how to use the library
- describe philosophy of the project
  - python 3.7 - no dependencies
  - use types and type hints extensively to provide auto-completion and documentation for OSC messages and API
  